@@ -5,6 +5,7 @@ import (
 	"html/template"
 	"net/http"
 	"strings"
+	"time"
 
 	ctstatic "github.com/boypt/simple-torrent/static"
 	"github.com/jpillora/velox"
@@ -62,9 +63,13 @@ func (s *Server) webHandle(w http.ResponseWriter, r *http.Request) {
 	case "download":
 		s.dlfilesh.ServeHTTP(w, r)
 	case s.baseInfo.Version:
+		w.Header().Set("Expires", time.Now().UTC().AddDate(0, 6, 0).Format(http.TimeFormat))
+		w.Header().Set("Cache-Control", "max-age:290304000, public")
 		s.verStatich.ServeHTTP(w, r)
 	default:
 		//no match, assume static file
+		w.Header().Set("Expires", time.Now().UTC().AddDate(0, 6, 0).Format(http.TimeFormat))
+		w.Header().Set("Cache-Control", "max-age:290304000, public")
 		s.statich.ServeHTTP(w, r)
 	}
 
