@@ -5,9 +5,11 @@ import (
 	"net/http"
 	"regexp"
 	"sort"
+	"strconv"
 	"strings"
 	"time"
 
+	"github.com/dustin/go-humanize"
 	"github.com/mmcdole/gofeed"
 )
 
@@ -24,6 +26,7 @@ type rssJSONItem struct {
 	Published       string `json:"published"`
 	URL             string `json:"url"`
 	Torrent         string `json:"torrent"`
+	Size            string `json:"size"`
 	publishedParsed *time.Time
 }
 
@@ -39,7 +42,7 @@ func (ritem *rssJSONItem) findFromFeedItem(i *gofeed.Item) (found bool) {
 	for _, e := range i.Enclosures {
 		if strings.HasPrefix(e.URL, "magnet:") {
 			ritem.Magnet = e.URL
-		} else if e.Type == "application/x-bittorrent" {
+		} else if torrentExp.Match([]byte(e.URL)) {
 			ritem.Torrent = e.URL
 		}
 	}
@@ -73,6 +76,17 @@ func (r *rssJSONItem) readExtention(i *gofeed.Item, ext string) (found bool) {
 	// There are no starndards for rss feeds contains torrents or magnets
 	// Heres some sites putting info in the extentions
 	if etor, ok := i.Extensions[ext]; ok {
+
+		if e, ok := etor["size"]; ok && len(e) > 0 {
+			r.Size = e[0].Value
+		}
+
+		if e, ok := etor["contentLength"]; ok && len(e) > 0 {
+			if size, err := strconv.ParseUint(e[0].Value, 10, 64); err == nil {
+				r.Size = humanize.Bytes(size)
+			}
+		}
+
 		if e, ok := etor["magnetURI"]; ok && len(e) > 0 {
 			r.Magnet = e[0].Value
 			found = true
@@ -163,12 +177,6 @@ func (s *Server) serveRSS(w http.ResponseWriter, r *http.Request) {
 		results = append(results, ritem)
 	}
 
-	b, err := json.Marshal(results)
-	if err != nil {
-		http.Error(w, err.Error(), http.StatusInternalServerError)
-		return
-	}
 	w.Header().Set("Content-Type", "application/json")
-	w.WriteHeader(http.StatusOK)
-	w.Write(b)
+	json.NewEncoder(w).Encode(results)
 }
